@@ -7,20 +7,32 @@ BALL_COLOR = (173, 255, 47)
 
 BOARD_COLOR = (233, 150, 122)
 
+SCORE_COLOR = (255, 255, 255)
+
 BOARD_SIZE = 500
 
-RACKET_LENGTH = 40
+RACKET_LENGTH = 50
 
 RACKET_HEIGHT = 10
 
-BALL_SPEED = 10
+DEFAULT_BALL_SPEED = 3
+
+MIN_BALL_SPPED = 7
+
+MAX_BALL_SPPED = 12
 
 BALL_SIZE = 10
 
-RACKET_SPEED = 5
+SCORE_TEXT_SIZE = 16
+
+SCORE_TEXT_SHIFT = 100
+
+RACKET_SPEED = 10
 
 WS_HEARTBEAT_TIMEOUT = 10
 
+FPS = 60
+
 LOGGING_LEVEL = logging.DEBUG
 
 SERVER_HOST = "0.0.0.0"
